package com.aliyun.alink.linksdk.alcs.lpbs.bridge;

import com.aliyun.alink.linksdk.alcs.lpbs.data.PalConnectParams;
import com.aliyun.alink.linksdk.alcs.lpbs.data.PalDeviceInfo;
import com.aliyun.alink.linksdk.alcs.lpbs.data.PalReqMessage;
import com.aliyun.alink.linksdk.alcs.lpbs.data.PalSubMessage;
import com.aliyun.alink.linksdk.alcs.lpbs.listener.PalConnectListener;
import com.aliyun.alink.linksdk.alcs.lpbs.listener.PalDeviceStateListener;
import com.aliyun.alink.linksdk.alcs.lpbs.listener.PalMsgListener;


/**
 * 连接的接口
 *
 */
public interface IPalConnect {
    /**
     * 连接设备接口
     *
     * @param params    连接的数据信息
     * @param listener  连接的回调接口
     */
    void startConnect(PalConnectParams params, PalConnectListener listener);

    /**
     * 断开设备接口
     *
     * @param deviceInfo    设备信息
     */
    void stopConnect(PalDeviceInfo deviceInfo);

    /**
     * 客户端发送信息给设备
     *
     * @param reqMessageInfo    请求的数据结构
     * @param callback          请求的回调接口
     * @return                  true表示发送正常，false表示发送异常
     */
    boolean asyncSendRequest(PalReqMessage reqMessageInfo, PalMsgListener callback);


//    boolean sendResponse(PalReqMessage reqMessageInfo, PalMsgListener callback, Object cbCtx);


    /**
     * 订阅设备事件的接口
     *
     * @param subMessageInfo    订阅请求的数据结构
     * @param callback          订阅是否成功的回调接口
     * @param eventListener     订阅成功后事件触发的回调接口
     * @return                  true表示是否发送成功，false表示发送异常
     */
    boolean subscribe(PalSubMessage subMessageInfo, PalMsgListener callback, PalMsgListener eventListener);

    /**
     * 取消订阅设备事件
     *
     * @param unsubMessageInfo  取消订阅请求的数据结构
     * @param callback          取消订阅是否成功的回调接口
     * @return                  true表示是否发送成功，false表示发送异常
     */
    boolean unsubscribe(PalSubMessage unsubMessageInfo, PalMsgListener callback);



    /**
     * 判断设备是否已连接
     *
     * @param deviceInfo    设备信息
     * @return              true表示在线，false表示不在线
     */
    boolean isDeviceConnected(PalDeviceInfo deviceInfo);


    /**
     * 注册设备状态的监听接口
     *
     * @param listener          设备状态的回调接口
     * @return                  true表示注册成功，false表示注册失败
     */
    boolean regDeviceStateListener(PalDeviceInfo deviceInfo,PalDeviceStateListener listener);

    /**
     * 注销设备状态的监听
     *
     * @param listener          设备状态的回调接口
     * @return                  true表示注销成功，false表示注销失败
     */
    boolean unregDeviceStateListener(PalDeviceInfo deviceInfo,PalDeviceStateListener listener);
}
